void		Beep();
int		nextword(unsigned char **);
unsigned char	*nextchar(unsigned char *);
XChar2b		*dup_16(XChar2b *);
void		printline(unsigned char *);
FILE		*open_compressed(char *);
TRANSLATION	FindField(TRANSLATION,
			  Boolean (*func)(TRANSLATION,void *),
			  void *);
int		FindIndex(char *);

int		isapipe(FILE *);

Boolean isMapped(Widget w);
